.. _contributing:

Contributing
============

Found a bug or got a feature request? Don't keep it for yourself, log a new
issue on the `GitHub project page`_.


.. _GitHub project page: https://github.com/christophercrouzet/nani/issues
